@@ -27,7 +27,7 @@ def __getattr__(name: str) -> Any:
         return NewForm
     """
 
-    if Form := getattr(OriginalClass, "form"):
+    if Form := getattr(OriginalClass, "form", None):
         Form = OriginalClass.form
         if not issubclass(Form, forms.FormMixin):
 
